@@ -17,6 +17,9 @@
 package org.osgi.util.converter;
 
 import java.lang.annotation.Annotation;
+import java.lang.invoke.MethodHandles;
+import java.lang.invoke.MethodHandles.Lookup;
+import java.lang.invoke.MethodType;
 import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
@@ -810,6 +813,32 @@ class ConvertingImpl extends AbstractSpecifying<Converting>
 					if (cls.isAnnotation()) {
 						val = method.getDefaultValue();
 					}
+					else if (method.isDefault())
+					{
+						double javaVersion = Double.parseDouble(
+							System.getProperty("java.class.version"));
+						double java8 = 52.0;
+						if (javaVersion > java8)
+						{
+							val = MethodHandles.lookup().findSpecial(
+								method.getDeclaringClass(), method.getName(),
+								MethodType.methodType(method.getReturnType(),
+									new Class[] {}),
+								method.getDeclaringClass()).bindTo(
+									proxy).invokeWithArguments(args);
+						}
+						else
+						{
+							Constructor<Lookup> c = Lookup.class.getDeclaredConstructor(
+								Class.class);
+							if (!c.isAccessible())
+							{
+								c.setAccessible(true);
+							}
+							val = c.newInstance(cls).in(cls).unreflectSpecial(method,
+								cls).bindTo(proxy).invokeWithArguments(args);
+						}
+					}
 
 					if (val == null) {
 						if (args != null && args.length == 1) {
@@ -886,7 +915,9 @@ class ConvertingImpl extends AbstractSpecifying<Converting>
 			}
 		} else if (Number.class.isAssignableFrom(targetAsClass)) {
 			if (object instanceof Boolean) {
-				return ((Boolean) object).booleanValue() ? 1 : 0;
+				return c.convert(((Boolean) object).booleanValue() ? 1 : 0)
+	                    .targetAs(targetAsClass)
+	                    .to(targetType);
 			} else if (object instanceof Number) {
 				if (Byte.class.isAssignableFrom(targetAsClass)) {
 					return ((Number) object).byteValue();
@@ -1126,11 +1157,15 @@ class ConvertingImpl extends AbstractSpecifying<Converting>
 		Set<Class< ? >> interfaces = getInterfaces0(cls);
 		outer: for (Iterator<Class< ? >> it = interfaces.iterator(); it.hasNext();) {
 			Class< ? > intf = it.next();
-			for (Method method : intf.getMethods()) {
+			Method[] methods=intf.getMethods();
+			for (Method method : methods) {
 				if(method.getDeclaringClass() == intf) {
 					continue outer;
 				}
 			}
+			if(intf==cls&&methods.length==0) {
+			    continue outer;
+			}
 			it.remove();
 		}
 
