@@ -16,12 +16,15 @@
  */
 package org.osgi.util.converter;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
-import org.osgi.framework.Version;
-import org.osgi.util.converter.MyDTO.Count;
-import org.osgi.util.converter.MyEmbeddedDTO.Alpha;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.lang.reflect.Array;
 import java.lang.reflect.Type;
@@ -30,11 +33,17 @@ import java.math.BigInteger;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
+import java.time.Duration;
+import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
+import java.time.Month;
+import java.time.MonthDay;
 import java.time.OffsetDateTime;
 import java.time.OffsetTime;
+import java.time.Year;
+import java.time.YearMonth;
 import java.time.ZonedDateTime;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -68,15 +77,12 @@ import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
+import org.osgi.framework.Version;
+import org.osgi.util.converter.MyDTO.Count;
+import org.osgi.util.converter.MyEmbeddedDTO.Alpha;
 
 public class ConverterTest {
     private Converter converter;
@@ -343,13 +349,13 @@ public class ConverterTest {
         assertArrayEquals(new char [] {'x', 'y'}, ca4b);
         assertNotSame("Should have created a new instance", ca4a, ca4b);
     }
-    
+
     /**
      * 707.4.3.1 - null becomes an empty array
      */
     @Test
     public void testNullToArrayConversion() {
-    	
+
     	checkArray(String[].class);
     	checkArray(boolean[].class);
     	checkArray(byte[].class);
@@ -370,7 +376,7 @@ public class ConverterTest {
     	checkArray(long[][].class);
     	checkArray(double[][].class);
 
-    	
+
     	checkArray(String[][][].class);
     	checkArray(boolean[][][].class);
     	checkArray(byte[][][].class);
@@ -384,7 +390,7 @@ public class ConverterTest {
 
 	private void checkArray(Class<?> arrayType) {
 		assertTrue(arrayType.isArray());
-		
+
 		Object array = converter.convert(null).to(arrayType);
     	assertEquals(0, Array.getLength(array));
     	assertTrue(arrayType.isInstance(array));
@@ -635,6 +641,51 @@ public class ConverterTest {
         assertEquals(zdt, zdt2);
     }
 
+    @Test
+    public void testInstant() {
+    	Instant i = Instant.now();
+    	String s = converter.convert(i).to(String.class);
+    	assertTrue(s.length() > 0);
+    	Instant i2 = converter.convert(s).to(Instant.class);
+    	assertEquals(i, i2);
+    }
+
+    @Test
+    public void testMonthDay() {
+    	MonthDay md = MonthDay.of(Month.APRIL, 1);
+    	String s = converter.convert(md).to(String.class);
+    	assertTrue(s.length() > 0);
+    	MonthDay md2 = converter.convert(s).to(MonthDay.class);
+    	assertEquals(md, md2);
+    }
+
+    @Test
+    public void testYearMonth() {
+    	YearMonth ym = YearMonth.of(1999, Month.APRIL);
+    	String s = converter.convert(ym).to(String.class);
+    	assertTrue(s.length() > 0);
+    	YearMonth ym2 = converter.convert(s).to(YearMonth.class);
+    	assertEquals(ym, ym2);
+    }
+
+    @Test
+    public void testYear() {
+    	Year y = Year.of(1999);
+    	String s = converter.convert(y).to(String.class);
+    	assertTrue(s.length() > 0);
+    	Year y2 = converter.convert(s).to(Year.class);
+    	assertEquals(y, y2);
+    }
+
+    @Test
+    public void testDuration() {
+    	Duration d = Duration.ofSeconds(42);
+    	String s = converter.convert(d).to(String.class);
+    	assertTrue(s.length() > 0);
+    	Duration d2 = converter.convert(s).to(Duration.class);
+    	assertEquals(d, d2);
+    }
+
     @Test
     public void testCalendarDate() {
         Calendar cal = new GregorianCalendar(1971, 1, 13, 12, 37, 41);
@@ -1400,11 +1451,59 @@ public class ConverterTest {
         assertEquals(Integer.valueOf(0), inter.value());
     }
 
+    @Test
+    public void testMapToEmptyInterface() throws Exception {
+        Map<String, Object> map = new HashMap<String, Object>();
+        map.put("a", "b");
+        EmptyInterface i = Converters.standardConverter().convert(map).to(EmptyInterface.class);
+        assertNotNull(i);
+
+        EmptyInterface2 j = Converters.standardConverter().convert(map).to(EmptyInterface2.class);
+        assertNotNull(j);
+
+        EmptyInterface3 k = Converters.standardConverter().convert(map).to(EmptyInterface3.class);
+        assertNotNull(k);
+    }
+
+    @Test
+    public void testDefaultInterfaceMethod() throws Throwable
+    {
+        Class<?> clazz = InterfaceWithDefaultMethod.class;
+        InterfaceWithDefaultMethod i = (InterfaceWithDefaultMethod) Converters.standardConverter().convert(
+            new HashMap<String, Object>()).to(clazz);
+        assertEquals(InterfaceWithDefaultMethod.RESULT, i.defaultMethod());
+    }
+
+    @Test
+    public void testConvertBooleanToNumber() {
+        assertEquals(Byte.valueOf((byte) 1), converter.convert(Boolean.TRUE).to(Byte.class));
+        assertEquals(Short.valueOf((short) 1), converter.convert(Boolean.TRUE).to(Short.class));
+        assertEquals(Integer.valueOf(1), converter.convert(Boolean.TRUE).to(Integer.class));
+        assertEquals(Long.valueOf(1), converter.convert(Boolean.TRUE).to(Long.class));
+        assertEquals(Float.valueOf(1.0f), converter.convert(Boolean.TRUE).to(Float.class));
+        assertEquals(Double.valueOf(1.0), converter.convert(Boolean.TRUE).to(Double.class));
+    }
+
     static interface MyIntf2 {
         String code();
         Integer value();
     }
 
+    static interface EmptyInterface
+    {
+    }
+
+    static interface EmptyInterface2 extends EmptyInterface
+    {
+    }
+    static interface NonEmptyInterface
+    {
+       int a();
+    }
+
+    static interface EmptyInterface3 extends NonEmptyInterface
+    {
+    }
     static class MyClass2 {
         private final String value;
         public MyClass2(String v) {
